@@ -1,11 +1,16 @@
 #' Wrapper for \link[Seurat]{DimPlot}.
-#'
-#' @inheritParams doc_function
+#' 
+#' 
+#' @inheritParams doc_function 
 #' @param idents.keep \strong{\code{\link[base]{character}}} | Vector of identities to keep. This will effectively set the rest of the cells that do not match the identities provided to NA, therefore coloring them according to na.value parameter.
+#'
 #' @param shuffle \strong{\code{\link[base]{logical}}} | Whether to shuffle the cells or not, so that they are not plotted cluster-wise. Recommended.
+#' @param split.by.combined \strong{\code{\link[base]{logical}}} | Adds a combined view of the all the values before splitting them by \strong{\code{split.by}}. Think of this as a regular DimPlot added in front. This is set to \strong{\code{TRUE}} if \strong{\code{split.by}} is used in combination with \strong{\code{group.by}}.
+#' @param legend.dot.border \strong{\code{\link[base]{logical}}} | Adds a black border around the dots in the legend. 
 #' @param order \strong{\code{\link[base]{character}}} | Vector of identities to be plotted. Either one with all identities or just some, which will be plotted last.
 #' @param sizes.highlight \strong{\code{\link[base]{numeric}}} | Point size of highlighted cells using cells.highlight parameter.
 #' @return  A ggplot2 object containing a DimPlot.
+#' @md
 #' @export
 #'
 #' @example man/examples/examples_do_DimPlot.R
@@ -13,7 +18,9 @@ do_DimPlot <- function(sample,
                        reduction = NULL,
                        group.by = NULL,
                        split.by = NULL,
+                       split.by.combined = TRUE,
                        colors.use = NULL,
+                       colorblind = FALSE,
                        shuffle = TRUE,
                        order = NULL,
                        raster = FALSE,
@@ -39,6 +46,7 @@ do_DimPlot <- function(sample,
                        legend.nrow = NULL,
                        legend.icon.size = 4,
                        legend.byrow = FALSE,
+                       legend.dot.border = TRUE,
                        raster.dpi = 2048,
                        dims = c(1, 2),
                        font.size = 14,
@@ -73,7 +81,7 @@ do_DimPlot <- function(sample,
   # Check if the sample provided is a Seurat object.
   check_Seurat(sample = sample)
   
-  sample <- check_Assay5(sample)
+  #sample <- check_Assay5(sample)
   
   # Check the reduction.
   reduction <- check_and_set_reduction(sample = sample, reduction = reduction)
@@ -90,7 +98,10 @@ do_DimPlot <- function(sample,
                        "plot_cell_borders" = plot_cell_borders,
                        "plot.axes" = plot.axes,
                        "plot_density_contour" = plot_density_contour,
-                       "label.box" = label.box)
+                       "label.box" = label.box,
+                       "split.by.combined" = split.by.combined,
+                       "legend.dot.border" = legend.dot.border,
+                       "colorblind" = colorblind)
   check_type(parameters = logical_list, required_type = "logical", test_function = is.logical)
   # Check numeric parameters.
   numeric_list <- list("pt.size" = pt.size,
@@ -158,7 +169,21 @@ do_DimPlot <- function(sample,
                                        crayon_body(" have to be set to "),
                                        crayon_key("NULL"),
                                        crayon_body(".")))
+  
+  if (base::isTRUE(group_by_and_split_by_used)){
+    assertthat::assert_that(base::isTRUE(split.by.combined),
+                            msg = paste0(add_cross(), crayon_body("Parameter "),
+                                         crayon_key("split.by.combined"),
+                                         crayon_body(" must be set to "),
+                                         crayon_key("TRUE"),
+                                         crayon_body(" when using a combination of "),
+                                         crayon_key("split.by"),
+                                         crayon_body(" and "),
+                                         crayon_key("group.by"),
+                                         crayon_body(".")))
+  }
 
+  
   if (order_and_shuffle_used){
     warning(paste0(add_warning(), crayon_body("Setting up a custom order with paramter "),
                    crayon_key("order"),
@@ -243,21 +268,24 @@ do_DimPlot <- function(sample,
       highlighting_cells <- is.null(group.by) & is.null(split.by) & (!(is.null(cells.highlight)) | !(is.null(idents.highlight)))
       if (isTRUE(default_parameters)){
         # Generate the color scale based on the levels assigned to the sample.
-        generate_color_scale(levels(sample))
+        colors.use <- generate_color_scale(levels(sample), colorblind = colorblind)
+        colors.use <- colors.use[levels(sample)]
       } else if (isTRUE(group_by_is_used) | isTRUE(group_by_and_split_by_used)){
         # Retrieve the unique values in group.by metadata variable.
         data.use <- sample[[]][, group.by, drop = FALSE]
         # If the variable is a factor, use the levels as order. If not, order the values alphabetically.
         names.use <- if (is.factor(data.use[, 1])){levels(data.use[, 1])} else {sort(unique(data.use[, 1]))}
         # Generate the color scale to be used based on the unique values of group.by.
-        generate_color_scale(names.use)
+        colors.use <- generate_color_scale(names.use, colorblind = colorblind)
+        colors.use <- colors.use[names.use]
       } else if (isTRUE(split_by_is_used)){
         # Retrieve the unique values in split.by metadata variable.
         data.use <- sample[[]][, split.by, drop = FALSE]
         # If the variable is a factor, use the levels as order. If not, order the values alphabetically.
         names.use <- if (is.factor(data.use[, 1])){levels(data.use[, 1])} else {sort(unique(data.use[, 1]))}
         # Generate the color scale based on the unique values of split.by
-        generate_color_scale(names.use)
+        colors.use <- generate_color_scale(names.use, colorblind = colorblind)
+        colors.use <- colors.use[names.use]
       } else if (isTRUE(highlighting_cells)){
         # If the user wants to highlight some cells, use this color.
         colors.use <- "#0A305F"
@@ -287,21 +315,36 @@ do_DimPlot <- function(sample,
       colors.use <- check_consistency_colors_and_names(sample = sample,
                                                        colors = colors.use,
                                                        idents.keep = idents.keep)
+      if (is.null(idents.keep)){
+        colors.use <- colors.use[levels(sample)]
+      } else {
+        colors.use <- colors.use[levels(sample)[idents.keep]]
+      }
+      
       # When using group.by or a combination of group.by and split.by.
     } else if (isTRUE(group_by_is_used) | isTRUE(group_by_and_split_by_used)){
+      # Retrieve the unique values in group.by metadata variable.
+      data.use <- sample[[]][, group.by, drop = FALSE]
       # Check that the color palette has the right amount of named colors with regards to group.by values.
       colors.use <- check_consistency_colors_and_names(sample = sample,
                                                        colors = colors.use,
                                                        grouping_variable = group.by,
                                                        idents.keep = idents.keep)
+      names.use <- if (is.factor(data.use[, 1])){levels(data.use[, 1])} else {sort(unique(data.use[, 1]))}
+      colors.use <- colors.use[names.use]
       # When using split.by.
     } else if (isTRUE(split_by_is_used)){
+      # Retrieve the unique values in split.by metadata variable.
+      data.use <- sample[[]][, split.by, drop = FALSE]
       # Check that the color palette has the right amount of named colors with regards to split.by values.
       colors.use <- check_consistency_colors_and_names(sample = sample,
                                                        colors = colors.use,
                                                        grouping_variable = split.by,
                                                        idents.keep = idents.keep)
-    
+      
+      names.use <- if (is.factor(data.use[, 1])){levels(data.use[, 1])} else {sort(unique(data.use[, 1]))}
+      colors.use <- colors.use[names.use]
+      
       # When highlighting cells.
     } else if (isTRUE(highlighting_cells)){
       # Stop the execution if more than one color is provided to highlight the cells.
@@ -478,13 +521,28 @@ do_DimPlot <- function(sample,
                            raster = raster,
                            ncol = ncol)
     } # nocov end
-    p <- p &
-      ggplot2::guides(color = ggplot2::guide_legend(ncol = legend.ncol,
-                                                    nrow = legend.nrow,
-                                                    byrow = legend.byrow,
-                                                    override.aes = list(size = legend.icon.size),
-                                                    title = legend.title,
-                                                    title.position = legend.title.position))
+    
+    if (base::isTRUE(legend.dot.border)){
+      p <- p &
+           ggplot2::guides(color = ggplot2::guide_legend(ncol = legend.ncol,
+                                                         nrow = legend.nrow,
+                                                         byrow = legend.byrow,
+                                                         override.aes = list(size = legend.icon.size,
+                                                                             color = "black",
+                                                                             fill = colors.use,
+                                                                             shape = 21),
+                                                         title = legend.title,
+                                                         title.position = legend.title.position))
+    } else {
+      p <- p &
+           ggplot2::guides(color = ggplot2::guide_legend(ncol = legend.ncol,
+                                                         nrow = legend.nrow,
+                                                         byrow = legend.byrow,
+                                                         override.aes = list(size = legend.icon.size),
+                                                         title = legend.title,
+                                                         title.position = legend.title.position))
+    }
+    
 
     if (isTRUE(label)){
       if (isTRUE(label.box)){
@@ -610,7 +668,7 @@ do_DimPlot <- function(sample,
                           idents.keep = NULL,
                           sizes.highlight = sizes.highlight,
                           ncol = ncol,
-                          plot.title = "Combined",
+                          plot.title = ifelse(isTRUE(group_by_and_split_by_used), group.by, split.by),
                           plot.subtitle = NULL,
                           plot.caption = NULL,
                           legend.title = legend.title,
@@ -647,20 +705,25 @@ do_DimPlot <- function(sample,
                           axis.text.face = axis.text.face,
                           legend.title.face = legend.title.face,
                           legend.text.face = legend.text.face)
-    p.extra <- p.extra + ggplot2::theme(plot.title = ggplot2::element_text(hjust = 0.5))
+    p.extra <- p.extra + ggplot2::theme(plot.title = ggplot2::element_text(hjust = 0.5, color = "black"))
     # Add plot to list.
-    list.plots[[1]] <- p.extra
+    
+    if (base::isTRUE(split.by.combined)){
+      list.plots[[1]] <- p.extra
+    }
+    
 
     num_values <- length(unique_values)
     for (i in seq_len(num_values)){
       value <- unique_values[i]
       # Generate a middle layer for the missing values after split.by.
       sample.use <- sample[, sample@meta.data[, split.by] == value]
-
+      
+      group.by.value <- if (is.null(group.by)) {split.by} else {group.by}
       if (utils::packageVersion("Seurat") >= "4.1.0"){
         p.loop <- Seurat::DimPlot(sample.use,
                                   reduction = reduction,
-                                  group.by = if (is.null(group.by)) {split.by} else {group.by},
+                                  group.by = group.by.value,
                                   label = label,
                                   dims = dims,
                                   repel = repel,
@@ -677,7 +740,7 @@ do_DimPlot <- function(sample,
       } else { # nocov start
         p.loop <- Seurat::DimPlot(sample.use,
                                   reduction = reduction,
-                                  group.by = if (is.null(group.by)) {split.by} else {group.by},
+                                  group.by = group.by.value,
                                   label = label,
                                   dims = dims,
                                   repel = repel,
@@ -691,14 +754,35 @@ do_DimPlot <- function(sample,
                                   cols = colors.use,
                                   raster = raster)
       } # nocov end
+      
+      # Add plot.title.
       p.loop <- p.loop +
-                ggplot2::ggtitle(value) +
-                ggplot2::guides(color = ggplot2::guide_legend(title = legend.title,
-                                                              ncol = legend.ncol,
-                                                              nrow = legend.nrow,
-                                                              byrow = legend.byrow,
-                                                              override.aes = list(size = legend.icon.size),
-                                                              title.position = legend.title.position))
+                ggplot2::labs(title = value)
+      
+      
+      used.values <- unique(sample.use@meta.data[ , group.by.value])
+
+      if (base::isTRUE(legend.dot.border)){
+        p.loop <- p.loop &
+                  ggplot2::guides(color = ggplot2::guide_legend(ncol = legend.ncol,
+                                                                nrow = legend.nrow,
+                                                                byrow = legend.byrow,
+                                                                override.aes = list(size = legend.icon.size,
+                                                                                    color = "black",
+                                                                                    fill = colors.use[used.values],
+                                                                                    shape = 21),
+                                                                title = legend.title,
+                                                                title.position = legend.title.position))
+      } else {
+        p.loop <- p.loop &
+                  ggplot2::guides(color = ggplot2::guide_legend(ncol = legend.ncol,
+                                                                nrow = legend.nrow,
+                                                                byrow = legend.byrow,
+                                                                override.aes = list(size = legend.icon.size),
+                                                                title = legend.title,
+                                                                title.position = legend.title.position))
+      }
+      
       if (isTRUE(label)){
         if (isTRUE(label.box)){
           p.loop <- add_scale(p = p.loop,
@@ -796,6 +880,9 @@ do_DimPlot <- function(sample,
     p <- p + 
          patchwork::plot_annotation(theme = ggplot2::theme(legend.position = legend.position))
     
+    if (base::isTRUE(split.by.combined)){
+      p[[1]]$labels$title <- ifelse(isTRUE(group_by_and_split_by_used), group.by, split.by)
+    }
   }
    # If the user wants to highlight some of the cells.
   else if (highlighting_cells){
@@ -841,15 +928,30 @@ do_DimPlot <- function(sample,
                            cols = colors.use.highlight,
                            na.value = "#bfbfbf00")
     } # nocov end
-
-    p <- p &
-         ggplot2::ggtitle("") &
-         ggplot2::guides(color = ggplot2::guide_legend(title = legend.title,
-                                                       ncol = legend.ncol,
-                                                       nrow = legend.nrow,
-                                                       byrow = legend.byrow,
-                                                       override.aes = list(size = legend.icon.size),
-                                                       title.position = legend.title.position))
+    
+    # Remove unwanted "selected_cells" title.
+    p <- p & ggplot2::labs(title = "")
+    
+    if (base::isTRUE(legend.dot.border)){
+      p <- p &
+           ggplot2::guides(color = ggplot2::guide_legend(ncol = legend.ncol,
+                                                         nrow = legend.nrow,
+                                                         byrow = legend.byrow,
+                                                         override.aes = list(size = legend.icon.size,
+                                                                             color = "black",
+                                                                             fill = colors.use,
+                                                                             shape = 21),
+                                                         title = legend.title,
+                                                         title.position = legend.title.position))
+    } else {
+      p <- p &
+           ggplot2::guides(color = ggplot2::guide_legend(ncol = legend.ncol,
+                                                         nrow = legend.nrow,
+                                                         byrow = legend.byrow,
+                                                         override.aes = list(size = legend.icon.size),
+                                                         title = legend.title,
+                                                         title.position = legend.title.position))
+    }
    
     # Add cell borders.
     if (isTRUE(plot_cell_borders)){
@@ -865,7 +967,8 @@ do_DimPlot <- function(sample,
                                 reduction = reduction,
                                 group.by = group.by,
                                 split.by = split.by,
-                                n = 100)
+                                n = 100,
+                                skip.density = TRUE)
       base_layer_subset <- out$base_layer
       p$layers <- append(base_layer_subset, p$layers)
       p$layers <- append(na_layer, p$layers)
@@ -928,7 +1031,21 @@ do_DimPlot <- function(sample,
                         panel.background = ggplot2::element_rect(fill = "white", color = "white"),
                         legend.background = ggplot2::element_rect(fill = "white", color = "white"))
   }
-
+  
+  # Add font.family to geom_text and geom_label.
+  if (length(p$patches$plots) > 0){
+    num.plots <- length(p$patches$plots)
+  } else {
+    num.plots <- 1
+  }
+  for (plot.use in seq(1, num.plots)){
+    for (layer.use in seq(1, length(p[[plot.use]]$layers))){
+      if (sum(stringr::str_detect(class(p[[plot.use]]$layers[[layer.use]]$geom), "GeomText|GeomLabel"))){
+        p[[plot.use]]$layers[[layer.use]]$aes_params$family <- font.type
+      }
+    }
+  }
+  
 
   # Add plot title to the plots.
   if (!is.null(plot.title)){
