@@ -200,10 +200,18 @@ do_PathwayActivityHeatmap <- function(sample,
     suppressMessages({
       sample$group.by <- sample@meta.data[, group]
       
-      suppressWarnings({
-      df <- t(as.matrix(SeuratObject::GetAssayData(object = sample,
-                                      assay = "progeny",
-                                      slot = slot))) %>%
+      if (utils::packageVersion("Seurat") < "5.0.0"){
+        df <- t(as.matrix(SeuratObject::GetAssayData(object = sample,
+                                                     assay = "progeny",
+                                                     slot = slot)))
+      } else {
+        df <- t(as.matrix(SeuratObject::GetAssayData(object = sample,
+                                                     assay = "progeny",
+                                                     layer = slot)))
+      }
+      
+      
+      df <- df %>%
             as.data.frame() %>%
             tibble::rownames_to_column(var = "cell") %>%
             dplyr::left_join(y = {sample@meta.data[, "group.by", drop = FALSE] %>%
@@ -215,7 +223,7 @@ do_PathwayActivityHeatmap <- function(sample,
                                 values_to = "score") %>%
             dplyr::group_by(.data$group.by, .data$source) %>%
             dplyr::summarise(mean = mean(.data$score, na.rm = TRUE))
-      })
+      
       df.order <- df
       df.order[is.na(df.order)] <- 0
 
@@ -225,10 +233,19 @@ do_PathwayActivityHeatmap <- function(sample,
 
       if (!is.null(split.by)){
         sample$split.by <- sample@meta.data[, split.by]
-        suppressWarnings({
-        df.split <- t(as.matrix(SeuratObject::GetAssayData(object = sample,
-                                              assay = "progeny",
-                                              slot = slot))) %>%
+        
+        if (utils::packageVersion("Seurat") < "5.0.0"){
+          df.split <- t(as.matrix(SeuratObject::GetAssayData(object = sample,
+                                                             assay = "progeny",
+                                                             slot = slot)))
+        } else {
+          df.split <- t(as.matrix(SeuratObject::GetAssayData(object = sample,
+                                                             assay = "progeny",
+                                                             layer = slot)))
+        }
+        
+        
+        df.split <- df.split %>%
                     as.data.frame() %>%
                     tibble::rownames_to_column(var = "cell") %>%
                     dplyr::left_join(y = {sample@meta.data[, c("group.by", "split.by"), drop = FALSE] %>%
@@ -241,7 +258,7 @@ do_PathwayActivityHeatmap <- function(sample,
                     dplyr::group_by(.data$split.by, .data$group.by, .data$source) %>%
                     dplyr::summarise(mean = mean(.data$score, na.rm = TRUE))
         matrix.list[[group]][["df.split"]] <- df.split
-        })
+        
       }
     })
   }
