@@ -17,7 +17,7 @@
                                  features = c("EPC1", "TOX2"),
                                  joint = TRUE)
 
-  } else if (isFALSE(value)){
+  } else if (base::isFALSE(value)){
     message("This function can not be used without its suggested packages.")
     message("Check out which ones are needed using `SCpubr::state_dependencies()`.")
   }
